@@ -273,7 +273,7 @@ typedef union YYSTYPE
 {
 
 /* Line 1676 of yacc.c  */
-#line 147 "/usr/local/bob/hg/sip/sip-snapshot-4.10.3-f760366cea3b/sipgen/parser.y"
+#line 147 "/home/bob/hg/sip/sip-snapshot-4.10.4-f5574a061fd0/sipgen/parser.y"
 
     char            qchar;
     char            *text;
@@ -297,7 +297,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 301 "/usr/local/bob/hg/sip/sip-snapshot-4.10.3-f760366cea3b/sipgen/parser.h"
+#line 301 "/home/bob/hg/sip/sip-snapshot-4.10.4-f5574a061fd0/sipgen/parser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
